pub struct AssumeUnder4GB;Expand description
A marker to make callers acknowledge that a method computes 32-bit offsets or lengths,
and trying to compute past u32::MAX code units may result in integer overflow.
The default Rust behavior for integer overflow is panic on debug mode, and silent wrapping (which for offsets or lengths returns a wrong value) in release mode.