pub struct Utf16CodeUnits(pub u32);Expand description
A length or offset counted in 16-bit code units in an UTF-16 string. This type is used to more reliable work with lengths or offsets in different encodings.
Tuple Fields
0: u32Implementations
Sourceimpl Utf16CodeUnits
impl Utf16CodeUnits
const ZERO: Self
pub fn saturating_sub(self, value: Self) -> Self
pub fn to_usize_range(range: &Range<Self>) -> Range<usize>
Sourceimpl Utf16CodeUnits
impl Utf16CodeUnits
Sourcepub fn length_of(_: AssumeUnder4GB, string: &str) -> Self
pub fn length_of(_: AssumeUnder4GB, string: &str) -> Self
Returns the length of string in UTF-16 code units
pub fn length_of_char(char: char) -> Self
Sourcepub fn to_utf8_code_units_in(
self,
_: AssumeUnder4GB,
string: &str,
) -> Utf8CodeUnits
pub fn to_utf8_code_units_in( self, _: AssumeUnder4GB, string: &str, ) -> Utf8CodeUnits
Convert this UTF-16 offset in string to an UTF-8 (byte) offset
Sourcepub fn to_utf8_code_units_in_iter<S>(
self,
_: AssumeUnder4GB,
iter: impl IntoIterator<Item = S>,
) -> Utf8CodeUnits
pub fn to_utf8_code_units_in_iter<S>( self, _: AssumeUnder4GB, iter: impl IntoIterator<Item = S>, ) -> Utf8CodeUnits
Convert this UTF-16 offset in an iterator of strings, to an UTF-8 (byte) offset
Sourcepub fn to_utf32_code_units_in(self, string: &str) -> Utf32CodeUnits
pub fn to_utf32_code_units_in(self, string: &str) -> Utf32CodeUnits
Convert this UTF-16 offset in string to an UTF-32 offset
Note: this never overflows since the return value is always less than or equal to self as one UTF-32 code unit corresponds to one or two UTF-16 code units.