pub struct Utf32CodeUnits(pub u32);Expand description
A length or offset counted in 32-bit code units in UTF-32.
This is the same as counting Rust chars, Unicode scalar values, or Unicode code points.
This type is used to more reliable work with lengths or offsets in different encodings.
Tuple Fields
0: u32Implementations
Sourceimpl Utf32CodeUnits
impl Utf32CodeUnits
const ZERO: Self
pub fn saturating_sub(self, value: Self) -> Self
pub fn to_usize_range(range: &Range<Self>) -> Range<usize>
Sourceimpl Utf32CodeUnits
impl Utf32CodeUnits
Sourcepub fn length_of(_: AssumeUnder4GB, string: &str) -> Self
pub fn length_of(_: AssumeUnder4GB, string: &str) -> Self
Returns the length of string in UTF-32 code units (char count)
Sourcepub fn to_utf8_code_units_in(
self,
_: AssumeUnder4GB,
string: &str,
) -> Utf8CodeUnits
pub fn to_utf8_code_units_in( self, _: AssumeUnder4GB, string: &str, ) -> Utf8CodeUnits
Convert this UTF-32 (char) offset in string to an UTF-8 (byte) offset
Sourcepub fn to_utf16_code_units_in(
self,
_: AssumeUnder4GB,
string: &str,
) -> Utf16CodeUnits
pub fn to_utf16_code_units_in( self, _: AssumeUnder4GB, string: &str, ) -> Utf16CodeUnits
Convert this UTF-32 (char) offset in string to an UTF-16 offset