pub struct Utf32CodeUnits(pub usize);Expand description
A length or offset counted in 32-bit code units in UTF-32.
This is the same as counting Rust chars, Unicode scalar values, or Unicode code points.
This type is used to more reliable work with lengths or offsets in different encodings.
Tuple Fields
0: usizeImplementations